import { Observable, Trace, Utils, unsetValue } from '@nativescript/core';
import { resolveModuleName } from '@nativescript/core/module-name-resolver';
export class DOMHelper {
    static addCollectionToParent(propertyName, parent, items) {
        if (parent._addArrayFromBuilder) {
            parent._addArrayFromBuilder(propertyName, items);
        }
        else if (parent._addChildFromBuilder) {
            for (const item of items) {
                parent._addChildFromBuilder(propertyName, item);
            }
        }
        else {
            Trace.write(`Could not add children to view ${parent}`, Trace.categories.ViewHierarchy);
        }
    }
    static addChildrenToParent(parent, children) {
        if (parent._addChildFromBuilder) {
            for (const child of children) {
                if (child) {
                    parent._addChildFromBuilder(child._tagName, child);
                }
            }
        }
    }
    static loadCustomModule(uri, ext) {
        if (ext) {
            uri = uri.substring(0, uri.length - (ext.length + 1));
        }
        const resolvedModuleName = resolveModuleName(uri, ext);
        return resolvedModuleName ? global.loadModule(resolvedModuleName, true) : null;
    }
    static setViewPropertyValue(view, propertyName, propertyValue, isEvent, notifyForChanges = true) {
        let propertyOwner = view;
        if (propertyName.indexOf('.') !== -1) {
            const properties = propertyName.split('.');
            for (let i = 0, length = properties.length - 1; i < length; i++) {
                if (propertyOwner != null) {
                    propertyOwner = propertyOwner[properties[i]];
                }
            }
            propertyName = properties[properties.length - 1];
        }
        // Use unset value as default if expression result is undefined
        if (Utils.isUndefined(propertyValue)) {
            propertyValue = unsetValue;
        }
        if (propertyOwner != null) {
            if (isEvent) {
                const handlerPropertyName = `_${propertyName}_handler`;
                // Check if old handler is a function and remove it from listeners
                if (Utils.isFunction(propertyOwner[handlerPropertyName])) {
                    propertyOwner.off(propertyName, propertyOwner[handlerPropertyName]);
                    delete propertyOwner[handlerPropertyName];
                }
                // Check if new handler is a function and add it to listeners
                if (Utils.isFunction(propertyValue)) {
                    propertyOwner.on(propertyName, propertyValue);
                    propertyOwner[handlerPropertyName] = propertyValue;
                }
            }
            else if (!notifyForChanges && propertyOwner instanceof Observable) {
                propertyOwner.set(propertyName, propertyValue);
            }
            else {
                propertyOwner[propertyName] = propertyValue;
            }
        }
    }
}
//# sourceMappingURL=dom-helper.js.map